==> nextcloud-app-mail-3.2.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/az.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Vacib",
    "Work" : "İş",
    "Personal" : "Şəxsi",
    "Mail" : "Məktub",
    "Name" : "Ad",
    "Password" : "Şifrə",
    "None" : "Heç bir",
    "SMTP Password" : "SMTP Şifrəsi",
    "Save" : "Saxla",
    "Connect" : "Qoşul",
    "Cancel" : "Dayandır",
    "Send" : "Göndər",
    "Choose a file to add as attachment" : "Əlavə ediləcək faylı seçin",
    "Favorite" : "İstəkli",
    "Read" : "Oxu",
    "Select" : "Select",
    "Create" : "Yarat",
    "Comment" : "Komentariya",
    "Choose" : "Seç",
    "Other" : "Digər",
    "Reply" : "Cavab",
    "Choose a folder to store the attachment in" : "Əlavələrin saxlanılması üçün qovluğu seçin",
    "Move" : "Move",
    "Quota" : "Norma",
    "Mark all as read" : "Hamısını oxunulmuş kimi qeydə al",
    "Clear cache" : "Keşi təmizlə",
    "Refresh" : "Yenilə",
    "Sending …" : "Göndərilir...",
    "Delete" : "Sil",
    "Add" : "Əlavə etmək",
    "Close" : "Bağla",
    "Tags" : "Işarələr",
    "Search" : "Axtarış",
    "Date" : "Date",
    "Disabled" : "Dayandırılıb",
    "Enabled" : "İşə salınıb",
    "Remove" : "Sil",
    "Reset" : "Sıfırla",
    "Client ID" : "Müştəri İD-s",
    "Client secret" : "Müxtəri sirri",
    "General" : "Ümumi",
    "User" : "User",
    "Host" : "Şəbəkədə ünvan",
    "Port" : "Port",
    "Valid until" : "Vaxtadək keçərlidir",
    "Archive" : "Arxiv",
    "All" : "Hamısı",
    "Drafts" : "Qaralamalar",
    "Favorites" : "Sevimlilər",
    "Inbox" : "Gələn qutusu",
    "Junk" : "Önəmsiz",
    "Sent" : "Göndərildi",
    "Trash" : "Zibil",
    "Error loading message" : "Mesajın yüklənməsində səhv baş verdi"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-mail-3.5.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/az.js <==
OC.L10N.register(
    "mail",
    {
    "Important" : "Vacib",
    "Work" : "İş",
    "Personal" : "Şəxsi",
    "Mail" : "Məktub",
    "Name" : "Ad",
    "Password" : "Şifrə",
    "None" : "Heç bir",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "SMTP Password" : "SMTP Şifrəsi",
    "Save" : "Saxla",
    "Connect" : "Qoşul",
    "Cancel" : "Dayandır",
    "Enter a date" : "Tarixi əlavə edin",
    "Send" : "Göndər",
    "Choose a file to add as attachment" : "Əlavə ediləcək faylı seçin",
    "Favorite" : "İstəkli",
    "Read" : "Oxu",
    "Select" : "Select",
    "Create" : "Yarat",
    "Comment" : "Komentariya",
    "Accept" : "Qəbul et",
    "Choose" : "Seç",
    "Other" : "Digər",
    "Reply" : "Cavab",
    "Choose a folder to store the attachment in" : "Əlavələrin saxlanılması üçün qovluğu seçin",
    "Move" : "Move",
    "Quota" : "Norma",
    "Mark all as read" : "Hamısını oxunulmuş kimi qeydə al",
    "Clear cache" : "Keşi təmizlə",
    "Refresh" : "Yenilə",
    "Sending …" : "Göndərilir...",
    "Delete" : "Sil",
    "Add" : "Əlavə etmək",
    "Close" : "Bağla",
    "Tags" : "Işarələr",
    "Search" : "Axtarış",
    "Date" : "Date",
    "Disabled" : "Dayandırılıb",
    "Enabled" : "İşə salınıb",
    "Remove" : "Sil",
    "Reset" : "Sıfırla",
    "Client ID" : "Müştəri İD-s",
    "Client secret" : "Müxtəri sirri",
    "General" : "Ümumi",
    "User" : "User",
    "Host" : "Şəbəkədə ünvan",
    "Port" : "Port",
    "Valid until" : "Vaxtadək keçərlidir",
    "Archive" : "Arxiv",
    "All" : "Hamısı",
    "Drafts" : "Qaralamalar",
    "Favorites" : "Sevimlilər",
    "Inbox" : "Gələn qutusu",
    "Junk" : "Önəmsiz",
    "Sent" : "Göndərildi",
    "Trash" : "Zibil",
    "Error loading message" : "Mesajın yüklənməsində səhv baş verdi"
},
"nplurals=2; plural=(n != 1);");
